@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007 Nominum, Inc.
+# Copyright (C) 2006, 2007, 2009-2011 Nominum, Inc.
 #
 # Permission to use, copy, modify, and distribute this software and its
 # documentation for any purpose with or without fee is hereby granted,
@@ -42,7 +42,7 @@ class IPSECKEY(dns.rdata.Rdata):
         super(IPSECKEY, self).__init__(rdclass, rdtype)
         if gateway_type == 0:
             if gateway != '.' and not gateway is None:
-                raise SyntaxError, 'invalid gateway for gateway type 0'
+                raise SyntaxError('invalid gateway for gateway type 0')
             gateway = None
         elif gateway_type == 1:
             # check that it's OK
@@ -53,8 +53,7 @@ class IPSECKEY(dns.rdata.Rdata):
         elif gateway_type == 3:
             pass
         else:
-            raise SyntaxError, \
-                  'invalid IPSECKEY gateway type: %d' % gateway_type
+            raise SyntaxError('invalid IPSECKEY gateway type: %d' % gateway_type)
         self.precedence = precedence
         self.gateway_type = gateway_type
         self.algorithm = algorithm
@@ -71,7 +70,7 @@ class IPSECKEY(dns.rdata.Rdata):
         elif self.gateway_type == 3:
             gateway = str(self.gateway.choose_relativity(origin, relativize))
         else:
-            raise ValueError, 'invalid gateway type'
+            raise ValueError('invalid gateway type')
         return '%d %d %d %s %s' % (self.precedence, self.gateway_type,
                                    self.algorithm, gateway,
                                    dns.rdata._base64ify(self.key))
@@ -86,17 +85,17 @@ class IPSECKEY(dns.rdata.Rdata):
             gateway = tok.get_string()
         chunks = []
         while 1:
-            t = tok.get()
-            if t[0] == dns.tokenizer.EOL or t[0] == dns.tokenizer.EOF:
+            t = tok.get().unescape()
+            if t.is_eol_or_eof():
                 break
-            if t[0] != dns.tokenizer.IDENTIFIER:
+            if not t.is_identifier():
                 raise dns.exception.SyntaxError
-            chunks.append(t[1])
+            chunks.append(t.value)
         b64 = ''.join(chunks)
         key = b64.decode('base64_codec')
         return cls(rdclass, rdtype, precedence, gateway_type, algorithm,
                    gateway, key)
-    
+
     from_text = classmethod(from_text)
 
     def to_wire(self, file, compress = None, origin = None):
@@ -112,9 +111,9 @@ class IPSECKEY(dns.rdata.Rdata):
         elif self.gateway_type == 3:
             self.gateway.to_wire(file, None, origin)
         else:
-            raise ValueError, 'invalid gateway type'
+            raise ValueError('invalid gateway type')
         file.write(self.key)
-        
+
     def from_wire(cls, rdclass, rdtype, wire, current, rdlen, origin = None):
         if rdlen < 3:
             raise dns.exception.FormError
@@ -140,8 +139,8 @@ class IPSECKEY(dns.rdata.Rdata):
             current += cused
             rdlen -= cused
         else:
-            raise dns.exception.FormError, 'invalid IPSECKEY gateway type'
-        key = wire[current : current + rdlen]
+            raise dns.exception.FormError('invalid IPSECKEY gateway type')
+        key = wire[current : current + rdlen].unwrap()
         return cls(rdclass, rdtype, header[0], gateway_type, header[2],
                    gateway, key)
 
@@ -156,5 +155,5 @@ class IPSECKEY(dns.rdata.Rdata):
         other.to_wire(f)
         wire2 = f.getvalue()
         f.close()
-        
+
         return cmp(wire1, wire2)
